@@ -126,21 +126,29 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
       if (is.null(pv$cols) & is.null(pv$range)) {
         self$param_set$values$cols = self$param_set$default[["cols"]] # nocov
       }
-      if (is.null(self$param_set$selection)) {
+      if (is.null(pv$selection)) {
         self$param_set$values$selection = self$param_set$default[["selection"]]
       }
 
       # Check for valid combinations of rows, cols and folds
-      if (!is.null(self$param_set$values$row) &&
-        !is.null(self$param_set$values$cols)) {
+      if (!is.null(pv$row) &&
+        !is.null(pv$cols)) {
         # nocov start
-        if ((self$param_set$values$rows * self$param_set$values$cols) <
-          self$param_set$values$folds) {
+        if ((pv$rows * pv$cols) <
+          pv$folds) {
           stopf("'nrow' * 'ncol' needs to be larger than 'folds'.")
         }
         # nocov end
       }
 
+      # checkerboard option only allows for two folds
+      if (self$param_set$values$selection == "checkerboard" &&
+        pv$folds > 2) {
+        mlr3misc::stopf("'selection = checkerboard' only allows for two folds.
+          Setting argument 'folds' to a value larger than would result in an empty test set.",
+          wrap = TRUE)
+      }
+
       groups = task$groups
 
       if (!is.null(groups)) {
@@ -178,8 +186,7 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
 
       create_blocks = function(coords, range) {
         points = sf::st_as_sf(coords,
-          coords = colnames(coords),
-          crs = crs)
+          coords = colnames(coords))
 
         # Suppress print message, warning crs and package load
         capture.output(inds <- suppressMessages(suppressWarnings(
@@ -198,7 +205,7 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
 
       inds = mlr3misc::map(seq_len(pv$repeats), function(i) {
         inds = create_blocks(coords, self$param_set$values$range[i])
-        blocks = sf::st_as_sf(inds$blocks, crs = crs)
+        blocks = sf::st_as_sf(inds$blocks)
 
         return(list(resampling = data.table(
           row_id = ids,
