@@ -1,5 +1,5 @@
 test_that("resampling iterations equals folds", {
-  task = test_make_twoclass()
+  task = test_make_twoclass_task()
   rsp = rsmp("spcv_env", folds = 2, features = "p_1")
   rsp$instantiate(task)
 
@@ -9,7 +9,7 @@ test_that("resampling iterations equals folds", {
 test_that("feature p_1 seperates the observations in two folds of equal size", {
   set.seed(1)
 
-  task = test_make_twoclass()
+  task = test_make_twoclass_task()
   rsp = rsmp("spcv_env", folds = 2, features = "p_1")
   rsp$instantiate(task)
 
@@ -20,14 +20,14 @@ test_that("feature p_1 seperates the observations in two folds of equal size", {
 })
 
 test_that("non-numeric feature throws an error", {
-  task = test_make_twoclass()
+  task = test_make_twoclass_task()
   rsp = rsmp("spcv_env", folds = 2, features = "p_2")
 
   expect_error(rsp$instantiate(task))
 })
 
 test_that("non-existing feature throws an error", {
-  task = test_make_twoclass()
+  task = test_make_twoclass_task()
   rsp = rsmp("spcv_env", folds = 2, features = "p_3")
 
   expect_error(rsp$instantiate(task))
